CADISHI compute kernels
=======================

The following documentation was automatically generated from the docstrings
present in the source code files.

.. toctree::
   :maxdepth: 2

cadishi.kernel
--------------

.. automodule:: cadishi.kernel
   :members:
   :undoc-members:

cadishi.kernel.common
---------------------

.. automodule:: cadishi.kernel.common
   :members:
   :undoc-members:

cadishi.kernel.dist
-------------------

.. automodule:: cadishi.kernel.dist
   :members:
   :undoc-members:

cadishi.kernel.pydh
-------------------

.. automodule:: cadishi.kernel.pydh
   :members:
   :undoc-members:

cadishi.kernel.cudh
-------------------

.. automodule:: cadishi.kernel.cudh
   :members:
   :undoc-members:
